Option Explicit
Option Strict

Imports System
Imports System.Data
Imports ByteFX.Data.MySqlClient
Imports System.Collections.Specialized
Imports System.XML

namespace BusObjVB
	
	''' <remarks> The PubsAccess class is the fundamental class for accessing information about authors in the system.</remarks>
	public class PubsAccess
		private m_connStr as String

		''' <summary> Initializes a new instance of the PubsAccess class. </summary>
		public Sub New()
			MyBase.new()
		end Sub

		''' <summary> An overloaded form of the PubAccess class constructor that takes a database connection string as an argument. </summary>
		''' <param name="connStr"> Connection string for the database. </param>
		public Sub New(connStr As String)
			MyBase.new()
			m_connStr = connStr
		end Sub

		''' <summary> Gets or sets the database connection string for the methods in this class that require database access.</summary>
		public Property DatabaseConnection as String
			set
				m_connStr = value
			end set
			get
				return m_connStr
			end get
		end Property

		''' <summary> Returns a DataSet with information on all of the authors in the system. </summary>
		''' <returns> A DataSet object populated with the names and IDs of authors in the system. </returns>
		''' <example>
		''' <code>
		''' BusObjVB.PubsAccess objPubs = new BusObjVB.PubsAccess();
		''' String dsn = "Data Source=localhost; Database=pubs; User Id=root; Password=";
		''' objPubs.DatabaseConnection = dsn;
		''' // Invoke the GetAuthors method
		''' DataSet authors = objPubs.GetAuthors();
		''' </code>
		''' </example>
		public function GetAuthors () as DataSet
			dim dbConnection as new MySQLConnection(m_connStr)
			dim authors as new DataSet()
			try
				dbConnection.Open()
				dim sqlCommand as new MySQLDataAdapter("SELECT au_id, concat(au_fname,' ',au_lname) AS au_name FROM authors", dbConnection)
				sqlCommand.Fill(authors, "authors")
			catch ex as MySQLException
				throw ex
			finally
				dbConnection.close()
			end try
			return authors
		end Function

		''' <summary> Returns all of the titles for a given author ID. </summary>
		''' <param name="authorID"> The ID of the author for which the titles should be retrieved. </param>
		''' <returns> A SringCollection populated with the tities for the AuthorID parameter submitted. </returns>
		''' <example>
		''' <code>
		''' BusObjVB.PubsAccess objPubs = new BusObjVB.PubsAccess();
		''' String dsn = "Data Source=localhost; Database=pubs; User Id=root; Password=";
		''' objPubs.DatabaseConnection = dsn;
		''' // Invoke the GetTitlesForAuthor method
		''' StringCollection titles = objPubs.GetTitlesForAuthor(Request.QueryString["auid"]);
		''' </code>
		''' </example>
		public function GetTitlesForAuthor (authorID as string) as StringCollection
			dim collTitles as new StringCollection()
			dim dbConnection as new MySQLConnection(m_connStr)
			dim titles as new DataSet()
			try
				dbConnection.Open()
				dim sqlCommand as new MySQLDataAdapter("SELECT title FROM titles INNER JOIN titleauthor ON titles.title_id = titleauthor.title_id WHERE (au_id = '" + authorID + "')", dbConnection)
				sqlCommand.Fill(titles, "titles")
			catch ex as MySQLException
				throw ex
			finally
				dbConnection.close()
			end try
			dim titleRows() as DataRow
			titleRows = titles.Tables("titles").Select()
			dim i as integer
			for i=0 to titleRows.Length - 1
				collTitles.Add (titleRows(i)("title").ToString())
				next i
			return collTitles
		end Function
		
		''' <summary> Calculates the total books sales for a given author ID. </summary>
		''' <param name="authorID"> The ID of the author for whom the total sales should be retrieved. </param>
		''' <returns> An integer which represents the total sales for the AuthorID submitted or 0 if no sales are recorded. </returns>
		''' <example>
		''' <code>
		''' BusObjVB.PubsAccess objPubs = new BusObjVB.PubsAccess();
		''' String dsn = "Data Source=localhost; Database=pubs; User Id=root; Password=";
		''' objPubs.DatabaseConnection = dsn;
		''' // Invoke the TotalSalesForAuthor method
		''' totalSales.Text = String.Format("{0:c}", objPubs.TotalSalesForAuthor(Request.QueryString["auid"]));
		''' </code>
		''' </example>
		public Function TotalSalesForAuthor (authorID as string) as integer
			dim dbConnection as new MySQLConnection(m_connStr)
			dim SalesTotal as new DataSet()
			try
				dbConnection.Open()
				dim sqlCommand as new MySQLDataAdapter("SELECT SUM(ytd_sales) AS TotalSales FROM titles INNER JOIN titleauthor ON titles.title_ID = titleauthor.title_id WHERE (au_id = '" + authorID + "')", dbConnection)
				sqlCommand.Fill(SalesTotal, "SalesTotal")
			catch ex as MySQLException
				throw ex
			finally
				dbConnection.close()
			end try
			dim titleTable as DataTable
			titleTable = SalesTotal.Tables("SalesTotal")
			if not titleTable.Rows(0).IsNull("TotalSales") then
				return CInt(titleTable.Rows(0)("TotalSales"))
			else
				return 0
			end if
		end Function
	end class
end namespace
