using System;
using System.Data;
using System.Collections.Specialized;
using System.Xml;
using BusObjCS;
using NUnit.Framework;

namespace BusObjTstCS {
	[TestFixture] public class BusObjTests {		
		public BusObjCS.PubsAccess objPubs;
		
		[SetUp] public void Init() {
			objPubs = new BusObjCS.PubsAccess();
			String dsn = "Data Source=localhost; Database=pubs; User Id=root; Password=";
			objPubs.DatabaseConnection = dsn;
          	}
		
		// Test that the proper XML dataset is returned when selecting all authors
		[Test] public void GetAllAuthors() {
			System.Console.WriteLine("Running GetAllAuthors()");
			DataSet testDataSet = new DataSet();
			testDataSet = objPubs.GetAuthors();
			DataSet matchDataSet = new DataSet();
			String pathXML = "..\\xmldata\\GetAllAuthors.xml";
			matchDataSet.ReadXml(pathXML);
			Assert.AreEqual(testDataSet.GetXml(), matchDataSet.GetXml(), "Incorrect first/last name match!");
        	}

		// Test that right titles and total number of titles are returned when more than one exist for a single author
		[Test] public void GetMultipleTitles() {
			System.Console.WriteLine("Running GetMutipleTitles()");
			StringCollection testTitles = new StringCollection();
			testTitles = objPubs.GetTitlesForAuthor("213-46-8915");
			Assert.AreEqual(true, testTitles.Contains("The Busy Executive's Database Guide"), "Incorrect match for Title 1!");
			Assert.AreEqual(true, testTitles.Contains("You Can Combat Computer Stress!"), "Incorrect match for Title 2!");
			Assert.AreEqual(2, testTitles.Count, "Incorrect number of members in collection");
		}

		// Test that a single, correct title is returned when only one exists for an author
		[Test] public void GetSingleTitle() {
			System.Console.WriteLine("Running GetSingleTitle()");
			StringCollection testTitles = new StringCollection();
			testTitles = objPubs.GetTitlesForAuthor("427-17-2319");
			Assert.AreEqual(true, testTitles.Contains("Secrets of Silicon Valley"), "Incorrect match for title!");
			Assert.AreEqual(1, testTitles.Count, "Incorrect number of members in collection");
		}

		// Test that no titles are returned when none exist for an author
		[Test] public void GetNoTitle() {
			System.Console.WriteLine("Running GetNoTitle()");
			StringCollection testTitles = new StringCollection();
			testTitles = objPubs.GetTitlesForAuthor("341-22-1782");
			Assert.AreEqual(0, testTitles.Count, "Incorrect number of members in collection");
		}

		// Test that the correct sales amount is returned for an author with mutiple sales figures
		[Test] public void TotalSalesMutipleBooks() {
			System.Console.WriteLine("Running TotalSalesMutipleBooks()");
			int sales = objPubs.TotalSalesForAuthor("213-46-8915");
			Assert.AreEqual(22817, sales, "Incorrect total for multiple books!");
		}

		// Test that the correct sales amount is returned for an author with one book
		[Test] public void TotalSalesSingleBook() {
			System.Console.WriteLine("Running TotalSalesSingleBook()");
			int sales = objPubs.TotalSalesForAuthor("427-17-2319");
			Assert.AreEqual(4095, sales, "Incorrect sales amount for single books!");
		}
		
		// Test that a zero sales amount is returned for an author with no books
		[Test] public void TotalSalesNoBook() {
			System.Console.WriteLine("Running TotalSalesNoBook()");
			int sales = objPubs.TotalSalesForAuthor("341-22-1782");
			Assert.AreEqual(0, sales, "Incorrect total with no books!");
		}	
	}
} 
