Option Explicit
Option Strict

Imports System
Imports System.Collections.Specialized
Imports System.Data
Imports System.XML
Imports BusObjVB
Imports NUnit.Framework

Namespace BusObjTstVB
	<TestFixture()> Public Class BusObjTests		
		Public objPubs As BusObjVB.PubsAccess
		
		Public Sub New()
            	MyBase.New()
        	End Sub

		<SetUp()> Public Sub Init()
			objPubs = New BusObjVB.PubsAccess()
			Dim dsn As String = "Data Source=localhost; Database=pubs; User Id=root; Password="
			objPubs.DatabaseConnection = dsn
          	End Sub

		'Test that the proper XML dataset is returned when selecting all authors
		<Test()> Public Sub GetAllAuthors()
			System.Console.WriteLine("Running GetAllAuthors()")
			Dim testDataSet As New DataSet()
			testDataSet = objPubs.GetAuthors()
			Dim matchDataSet As New DataSet()
			Dim pathXML As String = "..\xmldata\GetAllAuthors.xml"
			matchDataSet.readXML(pathXML)
			Assertion.AssertEquals("Incorrect first/last name match!", testDataSet.getXML(), matchDataSet.getXML())
        	End Sub

		'Test that right titles and total number of titles are returned when more than one exist for a single author
		<Test()> Public Sub GetMultipleTitles()
			System.Console.WriteLine("Running GetMutipleTitles()")
			Dim testTitles As New StringCollection()
			testTitles = objPubs.GetTitlesForAuthor("213-46-8915")
			Assertion.AssertEquals("Incorrect match for Title 1!", true, testTitles.contains("The Busy Executive's Database Guide"))
			Assertion.AssertEquals("Incorrect match for Title 2!", true, testTitles.contains("You Can Combat Computer Stress!"))
			Assertion.AssertEquals("Incorrect number of members in collection", 2, testTitles.count)  
		End Sub

		'Test that a single, correct title is returned when only one exists for an author
		<Test()> Public Sub GetSingleTitle()
			System.Console.WriteLine("Running GetSingleTitle()")
			Dim testTitles As New StringCollection()
			testTitles = objPubs.GetTitlesForAuthor("427-17-2319")
			Assertion.AssertEquals("Incorrect match for title!", true, testTitles.contains("Secrets of Silicon Valley"))
			Assertion.AssertEquals("Incorrect number of members in collection", 1, testTitles.count)  
		End Sub

		'Test that no titles are returned when none exist for an author
		<Test()> Public Sub GetNoTitle()
			System.Console.WriteLine("Running GetNoTitle()")
			Dim testTitles As New StringCollection()
			testTitles = objPubs.GetTitlesForAuthor("341-22-1782")
			Assertion.AssertEquals("Incorrect number of members in collection", 0, testTitles.count)  
		End Sub

		'Test that the correct sales amount is returned for an author with mutiple sales figures
		<Test()> Public Sub TotalSalesMutipleBooks()
			System.Console.WriteLine("Running TotalSalesMutipleBooks()")
			Dim sales as Integer
			sales = objPubs.TotalSalesForAuthor("213-46-8915")
			Assertion.AssertEquals("Incorrect total for multiple books!", 22817, sales)
		End Sub

		'Test that the correct sales amount is returned for an author with one book
		<Test()> Public Sub TotalSalesSingleBook()
			System.Console.WriteLine("Running TotalSalesSingleBook()")
			Dim sales as Integer
			sales = objPubs.TotalSalesForAuthor("427-17-2319")
			Assertion.AssertEquals("Incorrect sales amount for single books!", 4095, sales)
		End Sub

		'Test that a zero sales amount is returned for an author with no books
		<Test()> Public Sub TotalSalesNoBook()
			System.Console.WriteLine("Running TotalSalesNoBook()")
			Dim sales as Integer
			sales = objPubs.TotalSalesForAuthor("341-22-1782")
			Assertion.AssertEquals("Incorrect total with no books!", 0, sales)
		End Sub
		
	End Class
End Namespace 
